@@ -19,7 +19,6 @@ from IPython.core.application import SYSTEM_CONFIG_DIRS, ENV_CONFIG_DIRS
 from IPython.core import pylabtools
 from IPython.utils.contexts import preserve_keys
 from IPython.utils.path import filefind
-import traitlets
 from traitlets import (
     Unicode, Instance, List, Bool, CaselessStrEnum, observe,
     DottedObjectName,
@@ -98,11 +97,6 @@ shell_aliases = dict(
 )
 shell_aliases['cache-size'] = 'InteractiveShell.cache_size'
 
-if traitlets.version_info < (5, 0):
-    # traitlets 4 doesn't handle lists on CLI
-    shell_aliases["ext"] = "InteractiveShellApp.extra_extension"
-
-
 #-----------------------------------------------------------------------------
 # Main classes and functions
 #-----------------------------------------------------------------------------
@@ -126,17 +120,6 @@ class InteractiveShellApp(Configurable):
         help="A list of dotted module names of IPython extensions to load."
     ).tag(config=True)
 
-    extra_extension = Unicode(
-        "",
-        help="""
-        DEPRECATED. Dotted module name of a single extra IPython extension to load.
-
-        Only one extension can be added this way.
-
-        Only used with traitlets < 5.0, plural extra_extensions list is used in traitlets 5.
-        """,
-    ).tag(config=True)
-
     extra_extensions = List(
         DottedObjectName(),
         help="""
@@ -293,8 +276,6 @@ class InteractiveShellApp(Configurable):
             extensions = (
                 self.default_extensions + self.extensions + self.extra_extensions
             )
-            if self.extra_extension:
-                extensions.append(self.extra_extension)
             for ext in extensions:
                 try:
                     self.log.info("Loading IPython extension: %s" % ext)
@@ -331,6 +312,7 @@ class InteractiveShellApp(Configurable):
         # flush output, so itwon't be attached to the first cell
         sys.stdout.flush()
         sys.stderr.flush()
+        self.shell._sys_modules_keys = set(sys.modules.keys())
 
     def _run_exec_lines(self):
         """Run lines of code in IPythonApp.exec_lines in the user's namespace."""
